﻿using Microsoft.VisualBasic.FileIO;
using ProjectTourismCompany.Entities;
using ProjectTourismCompany.Entities.Enums;
using ProjectTourismCompany.Repositories;
using ProjectTourismCompany.Repositories.Implementations;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ProjectTourismCompany.Forms;

public partial class FormCompany : Form
{
    private readonly ICompanyRepository _companyRepository;
    private int? _companyId;
    public int Id
    {
        set
        {
            try
            {
                var client = _companyRepository.ReadCompanyById(value);
                if (client == null)
                {
                    throw new InvalidDataException(nameof(client));
                }

                textBoxName.Text = client.Name;
                comboBoxCountry.SelectedItem = client.CountryId;
                _companyId = value;
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка при получении данных", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
        }
    }




    public FormCompany(
    ICompanyRepository companyRepository,
    ITripRepository tripRepository,
    ICountryRepository countryRepository)
    {
        InitializeComponent();
        _companyRepository = companyRepository ??
        throw new ArgumentNullException(nameof(companyRepository));
        comboBoxCountry.DataSource = countryRepository.ReadCountries();
        comboBoxCountry.DisplayMember = "CountryName";
        comboBoxCountry.ValueMember = "Id";
    }


    private void ButtonSave_Click(object sender, EventArgs e)
    {
        try
        {
            if (string.IsNullOrEmpty(textBoxName.Text))
            {
            throw new Exception("Имеются незаполненные поля");
            }
            _companyRepository.CreateCompany(Company.CreateCompany(0, textBoxName.Text, (int)comboBoxCountry.SelectedItem!));
            Close();
        }
        catch (Exception ex)
        {
            MessageBox.Show(ex.Message, "Ошибка при сохранении",
            MessageBoxButtons.OK, MessageBoxIcon.Error);
        }
    }
    private void ButtonCancel_Click(object sender, EventArgs e) =>
    Close();
    
}
